@@ -81,6 +81,7 @@ import nbformat
 from nbconvert.preprocessors import ExecutePreprocessor
 
 from ASFProduct.test_ASFSubproduct import run_test_ASFSubproduct
+from tests.Search.test_collection_attributes import run_test_collection_attributes
 
 
 # asf_search.ASFProduct Tests
@@ -642,6 +643,12 @@ def test_keyword_aliasing_results(**args) -> None:
 
     run_test_keyword_aliasing_results(opts)
 
+def test_collection_attributes(**args) -> None:
+    params = args['test_info']['params']
+    expected_attributes = args['test_info']['expected_attributes']
+    expect_failure = args['test_info'].get('expect_failure', False)
+    session = args["config"].getoption("authenticated_session")
+    run_test_collection_attributes(params, expected_attributes, session, expect_failure)
 
 # Finds and loads file from yml_tests/Resouces/ if loaded field ends with .yml/yaml extension
 def get_resource(yml_file):
